==> plyr_1.2.1.tar.gz: plyr/man/splitter_d.Rd <==
\name{splitter_d}
\alias{splitter_d}
\title{Split a data frame by variables.}
\usage{splitter_d(data, .variables, drop=TRUE)}

\description{
  Split a data frame by variables. Split a data frame into pieces based
  on variable contained in that data frame
}

\details{
  This is the workhorse of the \code{d*ply} functions.  Based on the
  variables you supply, it breaks up a single data frame into a list of
  data frames, each containing a single combination from the levels of
  the specified variables.

  This is basically a thin wrapper around \code{\link{split}} which
  evaluates the variables in the context of the data, and includes
  enough information to reconstruct the labelling of the data frame
  after other operations.
}
\seealso{\code{\link{.}} for quoting variables, \code{\link{split}}}
\value{a list of data.frames, with attributes that record split details}
\keyword{internal}
\arguments{
  \item{data}{data frame}
  \item{.variables}{a \link{quoted} list of variables, a formula, or character vector.  \code{NULL} will not split the data}
  \item{drop}{drop unnused factor levels?}
}
\examples{plyr:::splitter_d(mtcars, .(cyl))
plyr:::splitter_d(mtcars, .(vs, am))
plyr:::splitter_d(mtcars, .(am, vs))

mtcars$cyl2 <- factor(mtcars$cyl, levels = c(2, 4, 6, 8, 10))
plyr:::splitter_d(mtcars, .(cyl2), drop = TRUE)
plyr:::splitter_d(mtcars, .(cyl2), drop = FALSE)

mtcars$cyl3 <- ifelse(mtcars$vs == 1, NA, mtcars$cyl)
plyr:::splitter_d(mtcars, .(cyl3))
plyr:::splitter_d(mtcars, .(cyl3, vs))
plyr:::splitter_d(mtcars, .(cyl3, vs), drop = FALSE)}

==> plyr_1.4.1.tar.gz: plyr/man/splitter_d.Rd <==
\name{splitter_d}
\alias{splitter_d}
\title{Split a data frame by variables.}
\usage{splitter_d(data, .variables, drop=TRUE)}

\description{
  Split a data frame by variables. Split a data frame into
  pieces based on variable contained in that data frame
}

\details{
  This is the workhorse of the \code{d*ply} functions.
  Based on the variables you supply, it breaks up a single
  data frame into a list of data frames, each containing a
  single combination from the levels of the specified
  variables.

  This is basically a thin wrapper around
  \code{\link{split}} which evaluates the variables in the
  context of the data, and includes enough information to
  reconstruct the labelling of the data frame after other
  operations.
}
\seealso{\code{\link{.}} for quoting variables, \code{\link{split}}}
\value{a list of data.frames, with attributes that record split details}
\keyword{internal}
\arguments{
  \item{data}{data frame}
  \item{.variables}{a \link{quoted} list of variables, a formula, or character vector.  \code{NULL} will not split the data}
  \item{drop}{drop unnused factor levels?}
}
\examples{plyr:::splitter_d(mtcars, .(cyl))
plyr:::splitter_d(mtcars, .(vs, am))
plyr:::splitter_d(mtcars, .(am, vs))

mtcars$cyl2 <- factor(mtcars$cyl, levels = c(2, 4, 6, 8, 10))
plyr:::splitter_d(mtcars, .(cyl2), drop = TRUE)
plyr:::splitter_d(mtcars, .(cyl2), drop = FALSE)

mtcars$cyl3 <- ifelse(mtcars$vs == 1, NA, mtcars$cyl)
plyr:::splitter_d(mtcars, .(cyl3))
plyr:::splitter_d(mtcars, .(cyl3, vs))
plyr:::splitter_d(mtcars, .(cyl3, vs), drop = FALSE)}
